/** Swarm status polling (5s heartbeat) */
export const SWARM_STATUS_POLL_MS = 5000;

/** Nodes polling (15s) */
export const NODES_POLL_MS = 15000;

/** Agents polling — definitions are static between reloads, poll infrequently */
export const AGENTS_POLL_MS = 60000;

/** Deploy status polling (10s) */
export const DEPLOY_POLL_MS = 10000;

/** Logs polling (5s) */
export const LOGS_POLL_MS = 5000;

/** Agent runs polling (5s) */
export const AGENT_RUNS_POLL_MS = 5000;

/** Restart health-check polling interval (1s) */
export const RESTART_POLL_INTERVAL_MS = 1000;

/** Restart timeout before giving up (30s) */
export const RESTART_TIMEOUT_MS = 30000;
